
/* package name */
#undef PACKAGE

/* version */
#undef VERSION

/* with dsp */
#undef WITH_DSP
#define DEV_DSP "/dev/dsp"

/* with dsp */
#undef WITH_CDROM 
#define DEV_CDROM "/dev/cdrom"

/* with dsp */
#undef WITH_MIXER
#define DEV_MIXER "/dev/mixer"

/* with DGA */
#define WITH_DGA 0

/* with screen saver */
#define WITH_SAVER 0

/* have ncurses */
#define HAVE_NCURSES 0

/* use any network code */
#define WITH_NETWORK 0

/* use OpenGL */
#define HAVE_GL 0

/* use MesaGL */
#define HAVE_MESA_GL 0

/* MP3 Player to use (path) */
#define MP3_PATH ""

/* MP3 Player to use (program) */
#define MP3_PLAYER 0

/* MOD Player to use */
#define MOD_PATH ""

/* MOD Player to use (program) */
#define MOD_PLAYER 0

/* the Xpm library is available */
#define USE_XPM 0

